@@ -45,6 +45,8 @@
 #include <eel/eel-string-list.h>
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
+#include <eel/eel-gtk-extensions.h>
+#include <gdk/gdkx.h>
 #include <gtk/gtksignal.h>
 #include <libgnome/gnome-config.h>
 #include <libgnome/gnome-i18n.h>
@@ -338,12 +340,13 @@ create_starthere_link_callback (gpointer data)
 	
 	/* Create default services icon on the desktop */
 	desktop_path = nautilus_get_desktop_directory ();
-	desktop_link_file = nautilus_make_path (desktop_path,
-						"starthere.desktop");
+	desktop_link_file = g_build_filename (desktop_path,
+					      "starthere.desktop",
+					      NULL);
 
 	cmd = g_strconcat ("/bin/cp ",
 			   NAUTILUS_DATADIR,
-			   "/starthere.desktop ",
+			   "/starthere-link.desktop ",
 			   desktop_link_file,
 			   NULL);
 
@@ -641,6 +644,82 @@ nautilus_window_delete_event_callback (GtkWidget *widget,
 	return TRUE;
 }				       
 
+static gboolean
+save_window_geometry_timeout (gpointer callback_data)
+{
+	NautilusWindow *window;
+	
+	window = NAUTILUS_WINDOW (callback_data);
+	
+	nautilus_window_save_geometry (window);
+
+	window->save_geometry_timeout_id = 0;
+	return FALSE;
+}
+ 
+static gboolean
+nautilus_window_configure_event_callback (GtkWidget *widget,
+						GdkEventConfigure *event,
+						gpointer callback_data)
+{
+	NautilusWindow *window;
+	char *geometry_string;
+	
+	window = NAUTILUS_WINDOW (widget);
+	
+	/* Only save the geometry if the user hasn't resized the window
+	 * for half a second. Otherwise delay the callback another half second.
+	 */
+	if (window->save_geometry_timeout_id != 0) {
+		g_source_remove (window->save_geometry_timeout_id);	
+	}
+	if (GTK_WIDGET_VISIBLE (GTK_WIDGET (window)) && !NAUTILUS_IS_DESKTOP_WINDOW (window)) {
+		
+		geometry_string = eel_gtk_window_get_geometry_string (GTK_WINDOW (window));
+	
+		/* If the last geometry is NULL the window must have just
+		 * been shown. No need to save geometry to disk since it
+		 * must be the same.
+		 */
+		if (window->last_geometry == NULL) {
+			window->last_geometry = geometry_string;
+			return FALSE;
+		}
+	
+		/* Don't save geometry if it's the same as before. */
+		if (!strcmp (window->last_geometry, geometry_string)) {
+			g_free (geometry_string);
+			return FALSE;
+		}
+
+		g_free (window->last_geometry);
+		window->last_geometry = geometry_string;
+
+		window->save_geometry_timeout_id = 
+				g_timeout_add (500, save_window_geometry_timeout, window);
+	}
+
+	return FALSE;
+}
+
+static gboolean
+nautilus_window_unrealize_event_callback (GtkWidget *widget,
+						GdkEvent *event,
+						gpointer callback_data)
+{
+	NautilusWindow *window;
+	
+	window = NAUTILUS_WINDOW (widget);
+
+	if (window->save_geometry_timeout_id != 0) {
+		g_source_remove (window->save_geometry_timeout_id);
+		window->save_geometry_timeout_id = 0;
+		nautilus_window_save_geometry (window);
+	}
+
+	return FALSE;
+}
+
 NautilusWindow *
 nautilus_application_create_window (NautilusApplication *application)
 {
@@ -658,6 +737,12 @@ nautilus_application_create_window (NautilusApplication *application)
 	g_signal_connect_object (window, "destroy",
 				 G_CALLBACK (nautilus_application_destroyed_window), application, 0);
 
+	g_signal_connect (window, "configure_event",
+			  G_CALLBACK (nautilus_window_configure_event_callback), NULL);
+
+	g_signal_connect (window, "unrealize",
+			  G_CALLBACK (nautilus_window_unrealize_event_callback), NULL);
+
 	nautilus_application_window_list = g_list_prepend (nautilus_application_window_list, window);
 
 	/* Do not yet show the window. It will be shown later on if it can
@@ -742,6 +827,21 @@ need_to_show_first_time_druid (void)
 	return result;
 }
 
+/* Apps like redhat-config-packages that are using the CD-ROM
+ * directly, can grab ownership of the _NAUTILUS_DISABLE_MOUNT_WINDOW
+ * selection to temporarily disable the new window behavior.
+ */
+static gboolean
+check_mount_window_disabled (void)
+{
+        Atom selection_atom = gdk_x11_get_xatom_by_name ("_NAUTILUS_DISABLE_MOUNT_WINDOW");
+
+        if (XGetSelectionOwner (GDK_DISPLAY(), selection_atom) != None)
+                return TRUE;
+	else
+		return FALSE;
+}
+
 static void
 volume_mounted_callback (NautilusVolumeMonitor *monitor, NautilusVolume *volume,
 			 NautilusApplication *application)
@@ -755,7 +855,8 @@ volume_mounted_callback (NautilusVolumeMonitor *monitor, NautilusVolume *volume,
 
 	/* Open a window to the CD if the user has set that preference. */
 	if (nautilus_volume_get_device_type (volume) == NAUTILUS_DEVICE_CDROM_DRIVE
-		&& eel_gconf_get_boolean( "/apps/magicdev/do_fileman_window")) {
+		&& eel_gconf_get_boolean( "/apps/magicdev/do_fileman_window")
+	        && !check_mount_window_disabled ()) {
 		window = nautilus_application_create_window (application);
 		uri = gnome_vfs_get_uri_from_local_path (nautilus_volume_get_mount_path (volume));
 		nautilus_window_go_to (window, uri);
@@ -890,7 +991,7 @@ set_session_restart (GnomeClient *client, gboolean restart)
 		/* Don't respawn in debug mode */
 		gnome_client_set_restart_style (client, GNOME_RESTART_IMMEDIATELY);
 	} else {
-		gnome_client_set_restart_style (client, GNOME_RESTART_NEVER);
+		gnome_client_set_restart_style (client, GNOME_RESTART_IF_RUNNING);
 	}
 }
 
@@ -926,6 +1027,8 @@ init_session (void)
 	update_session (client);
 }
 
+#ifdef UGLY_HACK_TO_DETECT_KDE
+
 static gboolean
 get_self_typed_prop (Window      xwindow,
                      Atom        atom,
@@ -1039,16 +1142,20 @@ look_for_kdesktop_recursive (Window xwindow)
 
 	return retval;
 }
+#endif /* UGLY_HACK_TO_DETECT_KDE */
 
 static gboolean
 is_kdesktop_present (void)
 {
+#ifdef UGLY_HACK_TO_DETECT_KDE
 	/* FIXME this is a pretty lame hack, should be replaced
 	 * eventually with e.g. a requirement that desktop managers
 	 * support a manager selection, ICCCM sec 2.8
 	 */
-
 	return look_for_kdesktop_recursive (GDK_ROOT_WINDOW ());
+#else
+	return FALSE;
+#endif
 }
 
 static void
