@@ -154,6 +154,7 @@ append_bookmark_node (gpointer data, gpointer user_data)
 		xmlSetProp (bookmark_node, "icon_name", icon_name);
 		nautilus_scalable_icon_unref (icon);
 		g_free (icon_uri);
+		g_free (icon_mime_type);
 		g_free (icon_name);
 	}
 }
@@ -327,7 +328,7 @@ nautilus_bookmark_list_get_file_path (NautilusBookmarkList *bookmarks)
 
 	if (file_path == NULL) {
 		user_directory = nautilus_get_user_directory ();
-		file_path = nautilus_make_path (user_directory, "bookmarks.xml");
+		file_path = g_build_filename (user_directory, "bookmarks.xml", NULL);
 		g_free (user_directory);
 	}
 
