@@ -62,8 +62,8 @@ struct NautilusWindowDetails
 
 	/* Toolbar. */
         GtkTooltips *tooltips;
-	BonoboUIToolbarButtonItem *back_button_item;
-	BonoboUIToolbarButtonItem *forward_button_item;
+	BonoboUIToolbarItem *back_button_item;
+	BonoboUIToolbarItem *forward_button_item;
 
         /* Current location. */
         char *location;
@@ -85,6 +85,7 @@ struct NautilusWindowDetails
 
         /* Throbber. */
         gboolean           throbber_active;
+        gboolean           throbber_activating;
 	Bonobo_PropertyBag throbber_property_bag;
 	Bonobo_Listener    throbber_listener;
 
@@ -133,6 +134,7 @@ void               nautilus_window_synch_view_as_menus                   (Nautil
 void               nautilus_window_initialize_menus_part_1               (NautilusWindow    *window);
 void               nautilus_window_initialize_menus_part_2               (NautilusWindow    *window);
 void               nautilus_window_initialize_toolbars                   (NautilusWindow    *window);
+void               nautilus_window_activate_throbber                     (NautilusWindow    *window);
 void		   nautilus_window_handle_ui_event_callback		 (BonoboUIComponent *ui,
 									  const char	    *id,
 									  Bonobo_UIComponent_EventType type,
@@ -142,7 +144,6 @@ void               nautilus_window_go_back                               (Nautil
 void               nautilus_window_go_forward                            (NautilusWindow    *window);
 void               nautilus_window_go_up                                 (NautilusWindow    *window);
 void               nautilus_window_update_find_menu_item                 (NautilusWindow    *window);
-void               nautilus_window_toolbar_remove_theme_callback         (NautilusWindow    *window);
 void               nautilus_window_remove_bookmarks_menu_callback        (NautilusWindow    *window);
 void               nautilus_window_remove_go_menu_callback               (NautilusWindow    *window);
 void               nautilus_window_remove_bookmarks_menu_items           (NautilusWindow    *window);
